#
# spec file for package ghc-persistent-sqlite
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent-sqlite
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.13.3.1
Release:        1.3
Summary:        Backend for the persistent library using sqlite3
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-conduit-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-microlens-th-devel
BuildRequires:  ghc-microlens-th-prof
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-monad-logger-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-persistent-devel
BuildRequires:  ghc-persistent-prof
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-resource-pool-prof
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-resourcet-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-time-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  glibc-devel
BuildRequires:  sqlite-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-HUnit-prof
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-fast-logger-devel
BuildRequires:  ghc-fast-logger-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-microlens-prof
BuildRequires:  ghc-persistent-test-devel
BuildRequires:  ghc-persistent-test-prof
BuildRequires:  ghc-system-fileio-devel
BuildRequires:  ghc-system-fileio-prof
BuildRequires:  ghc-system-filepath-devel
BuildRequires:  ghc-system-filepath-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
This package includes a thin sqlite3 wrapper based on the direct-sqlite
package, as well as the entire C library, so there are no system dependencies.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       glibc-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%define cabal_configure_options -f+systemlib
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue May 20 2025 Peter Simons <psimons@suse.com>
- Update persistent-sqlite to version 2.13.3.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-sqlite-2.13.3.1/src/ChangeLog.md
* Tue Jan 28 2025 Peter Simons <psimons@suse.com>
- Update copyright header. No functional change.
* Mon Dec 16 2024 Peter Simons <psimons@suse.com>
- Re-generate spec file with a recent versions of Cabal.
* Thu Dec  7 2023 Peter Simons <psimons@suse.com>
- Update persistent-sqlite to version 2.13.3.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-sqlite-2.13.3.0/src/ChangeLog.md
* Tue Oct  3 2023 Peter Simons <psimons@suse.com>
- Update persistent-sqlite to version 2.13.2.0.
  [#]# 2.13.2
  * [#1488](https://github.com/yesodweb/persistent/pull/1488)
  * Add `openRawSqliteConn` for creating `RawSqlite SqlBackend` connections
    that aren't automatically cleaned-up.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Jan 22 2023 Peter Simons <psimons@suse.com>
- Update persistent-sqlite to version 2.13.1.1.
  [#]# 2.13.1.1
  * [#1459](https://github.com/yesodweb/persistent/pull/1459)
  * Make use of `CautiousMigration` type alias for clarity.
* Sat Jan 29 2022 Peter Simons <psimons@suse.com>
- Update persistent-sqlite to version 2.13.1.0.
  [#]# 2.13.1.0
  * [#1341](https://github.com/yesodweb/persistent/pull/1341)
  * Add `SqlBackendHooks` to allow for instrumentation of queries.
  * [#1327](https://github.com/yesodweb/persistent/pull/1327)
  * Update backend to support new `StatementCache` interface
  [#]# 2.13.0.4
  * `aeson-2.0` support [#1351](https://github.com/yesodweb/persistent/pull/1351/)
* Thu May 27 2021 psimons@suse.com
- Update persistent-sqlite to version 2.13.0.3.
  [#]# 2.13.0.3
  * Somehow failed to properly release the safe-to-remove changes.
  [#]# 2.13.0.2
  * [#1275](https://github.com/yesodweb/persistent/pull/1275)
  * Fix SafeToRemove
* Wed May 26 2021 psimons@suse.com
- Update persistent-sqlite to version 2.13.0.2.
  [#]# 2.13.0.1
  * [#1265](https://github.com/yesodweb/persistent/pull/1265)
  * Support GHC 9
* Sat May  8 2021 psimons@suse.com
- Update persistent-sqlite to version 2.13.0.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri May  7 2021 psimons@suse.com
- Update persistent-sqlite to version 2.13.0.0.
  [#]# 2.13.0.0
  * [#1225](https://github.com/yesodweb/persistent/pull/1225)
  * Support `persistent-2.13` changes for SqlBackend being made internal.
* Wed Mar 31 2021 psimons@suse.com
- Update persistent-sqlite to version 2.12.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-sqlite-2.12.0.0/src/ChangeLog.md
* Mon Feb  8 2021 psimons@suse.com
- Update persistent-sqlite to version 2.11.1.0.
  [#]#  2.11.1.0
  * Add `checkForeignKeys` operation to verify no foreign key constraints are
    violated by the database contents.
  * Fix the migration for primary keys that was broken in 2.11.0.0
    [#1184](https://github.com/yesodweb/persistent/issues/1184)
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Nov  7 2020 psimons@suse.com
- Update persistent-sqlite to version 2.11.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/persistent-sqlite-2.11.0.0/src/ChangeLog.md
* Wed Aug 19 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 6GB min disk space for ppc64/ppc64le
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add persistent-sqlite at version 2.10.6.2.
